==> rhdm-7.8.1-sources.zip: rhba-7.8.1.GA-src/org.jbpm.contrib-workitems-7.39.0.Final-7.8.1/ethereum-workitem/src/test/java/org/jbpm/process/workitem/ethereum/test/EthereumWorkitemIntegrationTest.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jbpm.process.workitem.ethereum.test;

import java.util.Map;

import org.jbpm.process.workitem.WorkDefinitionImpl;
import org.jbpm.process.workitem.WorkItemRepository;
import org.junit.Test;

import static org.junit.Assert.*;

public class EthereumWorkitemIntegrationTest {

    @Test
    public void testWorkitemValidity() {

        String repoPath = "file://" + System.getProperty("builddir") +
                "/" + System.getProperty("artifactId") + "-" +
                System.getProperty("version") + "/";

        Map<String, WorkDefinitionImpl> repoResults = new WorkItemRepository().getWorkDefinitions(repoPath,
                                                                                                  null,
                                                                                                  System.getProperty("artifactId"));
        assertNotNull(repoResults);
        assertEquals(6,
                     repoResults.size());

        assertTrue(repoResults.containsKey("EthereumGetBalance"));
        assertTrue(repoResults.containsKey("EthereumSendEther"));
        assertTrue(repoResults.containsKey("EthereumQueryExistingContract"));
        assertTrue(repoResults.containsKey("EthereumTransactExistingContract"));
        assertTrue(repoResults.containsKey("EthereumDeployContract"));
        assertTrue(repoResults.containsKey("EthereumObserveContractEvent"));
    }
}

==> rhdm-7.10.1-sources.zip: rhba-7.10.1.GA-src/org.jbpm.contrib-workitems-7.48.0.Final-7.10.1/ethereum-workitem/src/test/java/org/jbpm/process/workitem/ethereum/test/EthereumWorkitemIntegrationTest.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jbpm.process.workitem.ethereum.test;

import java.util.Map;

import org.jbpm.process.workitem.WorkDefinitionImpl;
import org.jbpm.process.workitem.WorkItemRepository;
import org.junit.Test;

import static org.junit.Assert.*;

public class EthereumWorkitemIntegrationTest {

    @Test
    public void testWorkitemValidity() {

        String repoPath = "file:" + System.getProperty("builddir") +
                "/" + System.getProperty("artifactId") + "-" +
                System.getProperty("version") + "/";

        Map<String, WorkDefinitionImpl> repoResults = new WorkItemRepository().getWorkDefinitions(repoPath,
                                                                                                  null,
                                                                                                  System.getProperty("artifactId"));
        assertNotNull(repoResults);
        assertEquals(6,
                     repoResults.size());

        assertTrue(repoResults.containsKey("EthereumGetBalance"));
        assertTrue(repoResults.containsKey("EthereumSendEther"));
        assertTrue(repoResults.containsKey("EthereumQueryExistingContract"));
        assertTrue(repoResults.containsKey("EthereumTransactExistingContract"));
        assertTrue(repoResults.containsKey("EthereumDeployContract"));
        assertTrue(repoResults.containsKey("EthereumObserveContractEvent"));
    }
}
